# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from neurion.crucible import query_pb2 as neurion_dot_crucible_dot_query__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in neurion/crucible/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/neurion.crucible.Query/Params',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.GetCreators = channel.unary_unary(
                '/neurion.crucible.Query/GetCreators',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetCreatorsRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetCreatorsResponse.FromString,
                _registered_method=True)
        self.GetCreatorApplications = channel.unary_unary(
                '/neurion.crucible.Query/GetCreatorApplications',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetCreatorApplicationsRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetCreatorApplicationsResponse.FromString,
                _registered_method=True)
        self.GetTask = channel.unary_unary(
                '/neurion.crucible.Query/GetTask',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskResponse.FromString,
                _registered_method=True)
        self.ListAllTasks = channel.unary_unary(
                '/neurion.crucible.Query/ListAllTasks',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryListAllTasksRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryListAllTasksResponse.FromString,
                _registered_method=True)
        self.ListTasksByStatus = channel.unary_unary(
                '/neurion.crucible.Query/ListTasksByStatus',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryListTasksByStatusRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryListTasksByStatusResponse.FromString,
                _registered_method=True)
        self.GetSubmission = channel.unary_unary(
                '/neurion.crucible.Query/GetSubmission',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionResponse.FromString,
                _registered_method=True)
        self.GetSubmissionByTaskCreator = channel.unary_unary(
                '/neurion.crucible.Query/GetSubmissionByTaskCreator',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskCreatorRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskCreatorResponse.FromString,
                _registered_method=True)
        self.GetSubmissionByTask = channel.unary_unary(
                '/neurion.crucible.Query/GetSubmissionByTask',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskResponse.FromString,
                _registered_method=True)
        self.GetEncryptedProofOfOwnership = channel.unary_unary(
                '/neurion.crucible.Query/GetEncryptedProofOfOwnership',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetEncryptedProofOfOwnershipRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetEncryptedProofOfOwnershipResponse.FromString,
                _registered_method=True)
        self.GetPlagiarismReport = channel.unary_unary(
                '/neurion.crucible.Query/GetPlagiarismReport',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportResponse.FromString,
                _registered_method=True)
        self.GetTaskReward = channel.unary_unary(
                '/neurion.crucible.Query/GetTaskReward',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskRewardRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskRewardResponse.FromString,
                _registered_method=True)
        self.GetPendingCreatorApplications = channel.unary_unary(
                '/neurion.crucible.Query/GetPendingCreatorApplications',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetPendingCreatorApplicationsRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetPendingCreatorApplicationsResponse.FromString,
                _registered_method=True)
        self.GetTaskStake = channel.unary_unary(
                '/neurion.crucible.Query/GetTaskStake',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskStakeRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskStakeResponse.FromString,
                _registered_method=True)
        self.GetUnscoredSubmissionsByTask = channel.unary_unary(
                '/neurion.crucible.Query/GetUnscoredSubmissionsByTask',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetUnscoredSubmissionsByTaskRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetUnscoredSubmissionsByTaskResponse.FromString,
                _registered_method=True)
        self.CanTriggerFinalSubmission = channel.unary_unary(
                '/neurion.crucible.Query/CanTriggerFinalSubmission',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalSubmissionRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalSubmissionResponse.FromString,
                _registered_method=True)
        self.CanTriggerFinalTesting = channel.unary_unary(
                '/neurion.crucible.Query/CanTriggerFinalTesting',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalTestingRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalTestingResponse.FromString,
                _registered_method=True)
        self.CanRegisterAsTrainer = channel.unary_unary(
                '/neurion.crucible.Query/CanRegisterAsTrainer',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsTrainerRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsTrainerResponse.FromString,
                _registered_method=True)
        self.CanRegisterAsScorer = channel.unary_unary(
                '/neurion.crucible.Query/CanRegisterAsScorer',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsScorerRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsScorerResponse.FromString,
                _registered_method=True)
        self.IsTrainer = channel.unary_unary(
                '/neurion.crucible.Query/IsTrainer',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryIsTrainerRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryIsTrainerResponse.FromString,
                _registered_method=True)
        self.IsScorer = channel.unary_unary(
                '/neurion.crucible.Query/IsScorer',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryIsScorerRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryIsScorerResponse.FromString,
                _registered_method=True)
        self.CanSubmitTrainingResult = channel.unary_unary(
                '/neurion.crucible.Query/CanSubmitTrainingResult',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanSubmitTrainingResultRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanSubmitTrainingResultResponse.FromString,
                _registered_method=True)
        self.CanSubmitFinalResult = channel.unary_unary(
                '/neurion.crucible.Query/CanSubmitFinalResult',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanSubmitFinalResultRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanSubmitFinalResultResponse.FromString,
                _registered_method=True)
        self.CanRequestScoringTask = channel.unary_unary(
                '/neurion.crucible.Query/CanRequestScoringTask',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanRequestScoringTaskRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanRequestScoringTaskResponse.FromString,
                _registered_method=True)
        self.GetPendingScoringTasks = channel.unary_unary(
                '/neurion.crucible.Query/GetPendingScoringTasks',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetPendingScoringTasksRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetPendingScoringTasksResponse.FromString,
                _registered_method=True)
        self.CanTerminate = channel.unary_unary(
                '/neurion.crucible.Query/CanTerminate',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanTerminateRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanTerminateResponse.FromString,
                _registered_method=True)
        self.GetPlagiarismReportFromUser = channel.unary_unary(
                '/neurion.crucible.Query/GetPlagiarismReportFromUser',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportFromUserRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportFromUserResponse.FromString,
                _registered_method=True)
        self.GetScoreDisputeFromUser = channel.unary_unary(
                '/neurion.crucible.Query/GetScoreDisputeFromUser',
                request_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetScoreDisputeFromUserRequest.SerializeToString,
                response_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetScoreDisputeFromUserResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Parameters queries the parameters of the module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCreators(self, request, context):
        """Queries a list of GetCreators items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCreatorApplications(self, request, context):
        """Queries a list of GetCreatorApplications items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTask(self, request, context):
        """Queries a list of GetTask items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAllTasks(self, request, context):
        """Queries a list of ListAllTasks items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTasksByStatus(self, request, context):
        """Queries a list of ListTasksByStatus items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSubmission(self, request, context):
        """Queries a list of GetSubmission items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSubmissionByTaskCreator(self, request, context):
        """Queries a list of GetSubmissionByTaskCreator items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSubmissionByTask(self, request, context):
        """Queries a list of GetSubmissionByTask items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEncryptedProofOfOwnership(self, request, context):
        """Queries a list of GetEncryptedProofOfOwnership items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlagiarismReport(self, request, context):
        """Queries a list of GetPlagiarismReport items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskReward(self, request, context):
        """Queries a list of GetTaskReward items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPendingCreatorApplications(self, request, context):
        """Queries a list of GetPendingCreatorApplications items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskStake(self, request, context):
        """Queries a list of GetTaskStake items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUnscoredSubmissionsByTask(self, request, context):
        """Queries a list of GetUnscoredSubmissionsByTask items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanTriggerFinalSubmission(self, request, context):
        """Queries a list of CanTriggerFinalSubmission items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanTriggerFinalTesting(self, request, context):
        """Queries a list of CanTriggerFinalTesting items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanRegisterAsTrainer(self, request, context):
        """Queries a list of CanRegisterAsTrainer items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanRegisterAsScorer(self, request, context):
        """Queries a list of CanRegisterAsScorer items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsTrainer(self, request, context):
        """Queries a list of IsTrainer items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsScorer(self, request, context):
        """Queries a list of IsScorer items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanSubmitTrainingResult(self, request, context):
        """Queries a list of CanSubmitTrainingResult items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanSubmitFinalResult(self, request, context):
        """Queries a list of CanSubmitFinalResult items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanRequestScoringTask(self, request, context):
        """Queries a list of CanRequestScoringTask items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPendingScoringTasks(self, request, context):
        """Queries a list of GetPendingScoringTasks items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanTerminate(self, request, context):
        """Queries a list of CanTerminate items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlagiarismReportFromUser(self, request, context):
        """Queries a list of GetPlagiarismReportFromUser items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScoreDisputeFromUser(self, request, context):
        """Queries a list of GetScoreDisputeFromUser items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'GetCreators': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCreators,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetCreatorsRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetCreatorsResponse.SerializeToString,
            ),
            'GetCreatorApplications': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCreatorApplications,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetCreatorApplicationsRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetCreatorApplicationsResponse.SerializeToString,
            ),
            'GetTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTask,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskResponse.SerializeToString,
            ),
            'ListAllTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAllTasks,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryListAllTasksRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryListAllTasksResponse.SerializeToString,
            ),
            'ListTasksByStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTasksByStatus,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryListTasksByStatusRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryListTasksByStatusResponse.SerializeToString,
            ),
            'GetSubmission': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSubmission,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionResponse.SerializeToString,
            ),
            'GetSubmissionByTaskCreator': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSubmissionByTaskCreator,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskCreatorRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskCreatorResponse.SerializeToString,
            ),
            'GetSubmissionByTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSubmissionByTask,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskResponse.SerializeToString,
            ),
            'GetEncryptedProofOfOwnership': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEncryptedProofOfOwnership,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetEncryptedProofOfOwnershipRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetEncryptedProofOfOwnershipResponse.SerializeToString,
            ),
            'GetPlagiarismReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPlagiarismReport,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportResponse.SerializeToString,
            ),
            'GetTaskReward': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskReward,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskRewardRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskRewardResponse.SerializeToString,
            ),
            'GetPendingCreatorApplications': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPendingCreatorApplications,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetPendingCreatorApplicationsRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetPendingCreatorApplicationsResponse.SerializeToString,
            ),
            'GetTaskStake': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskStake,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskStakeRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetTaskStakeResponse.SerializeToString,
            ),
            'GetUnscoredSubmissionsByTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUnscoredSubmissionsByTask,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetUnscoredSubmissionsByTaskRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetUnscoredSubmissionsByTaskResponse.SerializeToString,
            ),
            'CanTriggerFinalSubmission': grpc.unary_unary_rpc_method_handler(
                    servicer.CanTriggerFinalSubmission,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalSubmissionRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalSubmissionResponse.SerializeToString,
            ),
            'CanTriggerFinalTesting': grpc.unary_unary_rpc_method_handler(
                    servicer.CanTriggerFinalTesting,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalTestingRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalTestingResponse.SerializeToString,
            ),
            'CanRegisterAsTrainer': grpc.unary_unary_rpc_method_handler(
                    servicer.CanRegisterAsTrainer,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsTrainerRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsTrainerResponse.SerializeToString,
            ),
            'CanRegisterAsScorer': grpc.unary_unary_rpc_method_handler(
                    servicer.CanRegisterAsScorer,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsScorerRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsScorerResponse.SerializeToString,
            ),
            'IsTrainer': grpc.unary_unary_rpc_method_handler(
                    servicer.IsTrainer,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryIsTrainerRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryIsTrainerResponse.SerializeToString,
            ),
            'IsScorer': grpc.unary_unary_rpc_method_handler(
                    servicer.IsScorer,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryIsScorerRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryIsScorerResponse.SerializeToString,
            ),
            'CanSubmitTrainingResult': grpc.unary_unary_rpc_method_handler(
                    servicer.CanSubmitTrainingResult,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanSubmitTrainingResultRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanSubmitTrainingResultResponse.SerializeToString,
            ),
            'CanSubmitFinalResult': grpc.unary_unary_rpc_method_handler(
                    servicer.CanSubmitFinalResult,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanSubmitFinalResultRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanSubmitFinalResultResponse.SerializeToString,
            ),
            'CanRequestScoringTask': grpc.unary_unary_rpc_method_handler(
                    servicer.CanRequestScoringTask,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanRequestScoringTaskRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanRequestScoringTaskResponse.SerializeToString,
            ),
            'GetPendingScoringTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPendingScoringTasks,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetPendingScoringTasksRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetPendingScoringTasksResponse.SerializeToString,
            ),
            'CanTerminate': grpc.unary_unary_rpc_method_handler(
                    servicer.CanTerminate,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryCanTerminateRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryCanTerminateResponse.SerializeToString,
            ),
            'GetPlagiarismReportFromUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPlagiarismReportFromUser,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportFromUserRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportFromUserResponse.SerializeToString,
            ),
            'GetScoreDisputeFromUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScoreDisputeFromUser,
                    request_deserializer=neurion_dot_crucible_dot_query__pb2.QueryGetScoreDisputeFromUserRequest.FromString,
                    response_serializer=neurion_dot_crucible_dot_query__pb2.QueryGetScoreDisputeFromUserResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'neurion.crucible.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('neurion.crucible.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/Params',
            neurion_dot_crucible_dot_query__pb2.QueryParamsRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCreators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetCreators',
            neurion_dot_crucible_dot_query__pb2.QueryGetCreatorsRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetCreatorsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCreatorApplications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetCreatorApplications',
            neurion_dot_crucible_dot_query__pb2.QueryGetCreatorApplicationsRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetCreatorApplicationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetTask',
            neurion_dot_crucible_dot_query__pb2.QueryGetTaskRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAllTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/ListAllTasks',
            neurion_dot_crucible_dot_query__pb2.QueryListAllTasksRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryListAllTasksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListTasksByStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/ListTasksByStatus',
            neurion_dot_crucible_dot_query__pb2.QueryListTasksByStatusRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryListTasksByStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSubmission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetSubmission',
            neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSubmissionByTaskCreator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetSubmissionByTaskCreator',
            neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskCreatorRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskCreatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSubmissionByTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetSubmissionByTask',
            neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetSubmissionByTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEncryptedProofOfOwnership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetEncryptedProofOfOwnership',
            neurion_dot_crucible_dot_query__pb2.QueryGetEncryptedProofOfOwnershipRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetEncryptedProofOfOwnershipResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPlagiarismReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetPlagiarismReport',
            neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTaskReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetTaskReward',
            neurion_dot_crucible_dot_query__pb2.QueryGetTaskRewardRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetTaskRewardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPendingCreatorApplications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetPendingCreatorApplications',
            neurion_dot_crucible_dot_query__pb2.QueryGetPendingCreatorApplicationsRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetPendingCreatorApplicationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTaskStake(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetTaskStake',
            neurion_dot_crucible_dot_query__pb2.QueryGetTaskStakeRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetTaskStakeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUnscoredSubmissionsByTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetUnscoredSubmissionsByTask',
            neurion_dot_crucible_dot_query__pb2.QueryGetUnscoredSubmissionsByTaskRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetUnscoredSubmissionsByTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanTriggerFinalSubmission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/CanTriggerFinalSubmission',
            neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalSubmissionRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalSubmissionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanTriggerFinalTesting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/CanTriggerFinalTesting',
            neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalTestingRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryCanTriggerFinalTestingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanRegisterAsTrainer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/CanRegisterAsTrainer',
            neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsTrainerRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsTrainerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanRegisterAsScorer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/CanRegisterAsScorer',
            neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsScorerRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryCanRegisterAsScorerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IsTrainer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/IsTrainer',
            neurion_dot_crucible_dot_query__pb2.QueryIsTrainerRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryIsTrainerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IsScorer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/IsScorer',
            neurion_dot_crucible_dot_query__pb2.QueryIsScorerRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryIsScorerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanSubmitTrainingResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/CanSubmitTrainingResult',
            neurion_dot_crucible_dot_query__pb2.QueryCanSubmitTrainingResultRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryCanSubmitTrainingResultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanSubmitFinalResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/CanSubmitFinalResult',
            neurion_dot_crucible_dot_query__pb2.QueryCanSubmitFinalResultRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryCanSubmitFinalResultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanRequestScoringTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/CanRequestScoringTask',
            neurion_dot_crucible_dot_query__pb2.QueryCanRequestScoringTaskRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryCanRequestScoringTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPendingScoringTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetPendingScoringTasks',
            neurion_dot_crucible_dot_query__pb2.QueryGetPendingScoringTasksRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetPendingScoringTasksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanTerminate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/CanTerminate',
            neurion_dot_crucible_dot_query__pb2.QueryCanTerminateRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryCanTerminateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPlagiarismReportFromUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetPlagiarismReportFromUser',
            neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportFromUserRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetPlagiarismReportFromUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetScoreDisputeFromUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.crucible.Query/GetScoreDisputeFromUser',
            neurion_dot_crucible_dot_query__pb2.QueryGetScoreDisputeFromUserRequest.SerializeToString,
            neurion_dot_crucible_dot_query__pb2.QueryGetScoreDisputeFromUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



import warnings
from dataclasses import dataclass
from typing import Optional, Union


class NetworkConfigError(RuntimeError):
    """Network config error.

    :param RuntimeError: Runtime error
    """


URL_PREFIXES = (
    "grpc+https",
    "grpc+http",
    "rest+https",
    "rest+http",
)


@dataclass
class NetworkConfig:
    """Network configurations.

    :raises NetworkConfigError: Network config error
    :raises RuntimeError: Runtime error
    """

    chain_id: str
    fee_minimum_gas_price: Union[int, float]
    fee_denomination: str
    staking_denomination: str
    url: str
    faucet_url: Optional[str] = None

    def validate(self):
        """Validate the network configuration.

        :raises NetworkConfigError: Network config error
        """
        if self.chain_id == "":
            raise NetworkConfigError("Chain id must be set")
        if self.url == "":
            raise NetworkConfigError("URL must be set")
        if not any(
            map(
                lambda x: self.url.startswith(  # noqa: # pylint: disable=unnecessary-lambda
                    x
                ),
                URL_PREFIXES,
            )
        ):
            prefix_list = ", ".join(map(lambda x: f'"{x}"', URL_PREFIXES))
            raise NetworkConfigError(
                f"URL must start with one of the following prefixes: {prefix_list}"
            )

    @classmethod
    def neurion_localnet(cls):
        return NetworkConfig(
            chain_id="neurion",
            url="grpc+http://0.0.0.0:9090",
            fee_minimum_gas_price=0,
            fee_denomination="union",
            staking_denomination="union",
            faucet_url=None,
        )

    @classmethod
    def neurion_alpha_testnet(cls):
        return NetworkConfig(
            chain_id="neurion",
            url="grpc+http://159.223.105.187:9090",
            fee_minimum_gas_price=0,
            fee_denomination="union",
            staking_denomination="union",
            faucet_url=None,
        )

    @classmethod
    def neurion_beta_testnet(cls):
        """Get the neurion beta testnet.

        :raises RuntimeError: No beta testnet available
        """
        raise RuntimeError("No beta testnet available")

    @classmethod
    def neurion_stable_testnet(cls):
        """Get the neurion stable testnet.

        :return: neurion stable testnet. For now dorado is neurion stable testnet.
        """
        return cls.neurion_stable_testnet()

    @classmethod
    def neurion_mainnet(cls) -> "NetworkConfig":
        """Get the neurion mainnet configuration.

        :return: neurion mainnet configuration
        """
        return NetworkConfig(
            chain_id="neurion",
            url="grpc+https://neurion.xyz",
            fee_minimum_gas_price=0,
            fee_denomination="afet",
            staking_denomination="afet",
            faucet_url=None,
        )


    @classmethod
    def latest_stable_testnet(cls) -> "NetworkConfig":
        """Get the latest stable testnet.

        :return: latest stable testnet
        """
        warnings.warn(
            "latest_stable_testnet is deprecated, use neurion_stable_testnet instead",
            DeprecationWarning,
        )
        return cls.neurion_stable_testnet()



from gogoproto import gogo_pb2 as _gogo_pb2
import proofs_pb2 as _proofs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MerkleRoot(_message.Message):
    __slots__ = ("hash",)
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    def __init__(self, hash: _Optional[bytes] = ...) -> None: ...

class MerklePrefix(_message.Message):
    __slots__ = ("key_prefix",)
    KEY_PREFIX_FIELD_NUMBER: _ClassVar[int]
    key_prefix: bytes
    def __init__(self, key_prefix: _Optional[bytes] = ...) -> None: ...

class MerklePath(_message.Message):
    __slots__ = ("key_path",)
    KEY_PATH_FIELD_NUMBER: _ClassVar[int]
    key_path: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, key_path: _Optional[_Iterable[str]] = ...) -> None: ...

class MerkleProof(_message.Message):
    __slots__ = ("proofs",)
    PROOFS_FIELD_NUMBER: _ClassVar[int]
    proofs: _containers.RepeatedCompositeFieldContainer[_proofs_pb2.CommitmentProof]
    def __init__(self, proofs: _Optional[_Iterable[_Union[_proofs_pb2.CommitmentProof, _Mapping]]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cometbft.types.v1beta1 import params_pb2 as _params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConsensusParams(_message.Message):
    __slots__ = ("block", "evidence", "validator", "version")
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    block: BlockParams
    evidence: _params_pb2.EvidenceParams
    validator: _params_pb2.ValidatorParams
    version: _params_pb2.VersionParams
    def __init__(self, block: _Optional[_Union[BlockParams, _Mapping]] = ..., evidence: _Optional[_Union[_params_pb2.EvidenceParams, _Mapping]] = ..., validator: _Optional[_Union[_params_pb2.ValidatorParams, _Mapping]] = ..., version: _Optional[_Union[_params_pb2.VersionParams, _Mapping]] = ...) -> None: ...

class BlockParams(_message.Message):
    __slots__ = ("max_bytes", "max_gas")
    MAX_BYTES_FIELD_NUMBER: _ClassVar[int]
    MAX_GAS_FIELD_NUMBER: _ClassVar[int]
    max_bytes: int
    max_gas: int
    def __init__(self, max_bytes: _Optional[int] = ..., max_gas: _Optional[int] = ...) -> None: ...



from abc import ABC, abstractmethod

from neurionpy.protos.cosmos.bank.v1beta1.query_pb2 import (
    QueryAllBalancesRequest,
    QueryAllBalancesResponse,
    QueryBalanceRequest,
    QueryBalanceResponse,
    QueryDenomMetadataRequest,
    QueryDenomMetadataResponse,
    QueryDenomsMetadataRequest,
    QueryDenomsMetadataResponse,
    QueryParamsRequest,
    QueryParamsResponse,
    QuerySupplyOfRequest,
    QuerySupplyOfResponse,
    QueryTotalSupplyRequest,
    QueryTotalSupplyResponse,
)


class Bank(ABC):
    """Bank abstract class."""

    @abstractmethod
    def Balance(self, request: QueryBalanceRequest) -> QueryBalanceResponse:
        """
        Query balance of selected denomination from specific account.

        :param request: QueryBalanceRequest with address and denomination

        :return: QueryBalanceResponse
        """

    @abstractmethod
    def AllBalances(self, request: QueryAllBalancesRequest) -> QueryAllBalancesResponse:
        """
        Query balance of all denominations from specific account.

        :param request: QueryAllBalancesRequest with account address

        :return: QueryAllBalancesResponse
        """

    @abstractmethod
    def TotalSupply(self, request: QueryTotalSupplyRequest) -> QueryTotalSupplyResponse:
        """
        Query total supply of all denominations.

        :param request: QueryTotalSupplyRequest

        :return: QueryTotalSupplyResponse
        """

    @abstractmethod
    def SupplyOf(self, request: QuerySupplyOfRequest) -> QuerySupplyOfResponse:
        """
        Query total supply of specific denomination.

        :param request: QuerySupplyOfRequest with denomination

        :return: QuerySupplyOfResponse
        """

    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Query the parameters of bank module.

        :param request: QueryParamsRequest

        :return: QueryParamsResponse
        """

    @abstractmethod
    def DenomMetadata(
        self, request: QueryDenomMetadataRequest
    ) -> QueryDenomMetadataResponse:
        """
        Query the client metadata for all registered coin denominations.

        :param request: QueryDenomMetadataRequest with denomination

        :return: QueryDenomMetadataResponse
        """

    @abstractmethod
    def DenomsMetadata(
        self, request: QueryDenomsMetadataRequest
    ) -> QueryDenomsMetadataResponse:
        """
        Query the client metadata of a given coin denomination.

        :param request: QueryDenomsMetadataRequest

        :return: QueryDenomsMetadataResponse
        """



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.ibc.applications.transfer.interface import (  # type: ignore
    IBCApplicationsTransfer,
)
from neurionpy.protos.ibc.applications.transfer.v1.query_pb2 import (
    QueryDenomTraceRequest,
    QueryDenomTraceResponse,
    QueryDenomTracesRequest,
    QueryDenomTracesResponse,
    QueryParamsRequest,
    QueryParamsResponse,
)


class IBCApplicationsTransferRestClient(IBCApplicationsTransfer):
    """IBC Applications Transfer REST client."""

    API_URL = "/ibc/applications/transfer/v1beta1"

    def __init__(self, rest_api: RestClient) -> None:
        """
        Initialize.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def DenomTrace(self, request: QueryDenomTraceRequest) -> QueryDenomTraceResponse:
        """
        DenomTrace queries a denomination trace information.

        :param request: QueryDenomTraceRequest
        :return: QueryDenomTraceResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/denom_traces/{request.hash}"
        )
        return Parse(json_response, QueryDenomTraceResponse())

    def DenomTraces(self, request: QueryDenomTracesRequest) -> QueryDenomTracesResponse:
        """
        DenomTraces queries all denomination traces.

        :param request: QueryDenomTracesRequest
        :return: QueryDenomTracesResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/denom_traces", request)
        return Parse(json_response, QueryDenomTracesResponse())

    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """
        Params queries all parameters of the ibc-transfer module.

        :param request: QueryParamsRequest
        :return: QueryParamsResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(json_response, QueryParamsResponse())



from datetime import timedelta
from typing import Any, Callable, List, Optional, Union

from neurionpy.synapse.tx import SigningCfg
from neurionpy.synapse.tx_helpers import SubmittedTx
from neurionpy.protos.cosmos.base.query.v1beta1.pagination_pb2 import PageRequest


def prepare_and_broadcast_basic_transaction(
    client: "LedgerClient",  # type: ignore # noqa: F821
    tx: "Transaction",  # type: ignore # noqa: F821
    sender: "Wallet",  # type: ignore # noqa: F821
    account: Optional["Account"] = None,  # type: ignore # noqa: F821
    gas_limit: Optional[int] = None,
    memo: Optional[str] = None,
) -> SubmittedTx:
    """Prepare and broadcast basic transaction.

    :param client: Ledger client
    :param tx: The transaction
    :param sender: The transaction sender
    :param account: The account
    :param gas_limit: The gas limit
    :param memo: Transaction memo, defaults to None

    :return: broadcast transaction
    """
    # query the account information for the sender
    if account is None:
        account = client.query_account(sender.address())

    if gas_limit is not None:
        # simply build the fee from the provided gas limit
        fee = client.estimate_fee_from_gas(gas_limit)
    else:
        # we need to build up a representative transaction so that we can accurately simulate it
        tx.seal(
            SigningCfg.direct(sender.public_key(), account.sequence),
            fee="",
            gas_limit=0,
            memo=memo,
        )
        tx.sign(sender.signer(), client.network_config.chain_id, account.number)
        tx.complete()

        # simulate the gas and fee for the transaction
        gas_limit, fee = client.estimate_gas_and_fee_for_tx(tx)

    # finally, build the final transaction that will be executed with the correct gas and fee values
    tx.seal(
        SigningCfg.direct(sender.public_key(), account.sequence),
        fee=fee,
        gas_limit=gas_limit,
        memo=memo,
    )
    tx.sign(sender.signer(), client.network_config.chain_id, account.number)
    tx.complete()

    return client.broadcast_tx(tx)


def ensure_timedelta(interval: Union[int, float, timedelta]) -> timedelta:
    """
    Return timedelta for interval.

    :param interval: timedelta or seconds in int or float

    :return: timedelta
    """
    return interval if isinstance(interval, timedelta) else timedelta(seconds=interval)


DEFAULT_PER_PAGE_LIMIT = None


def get_paginated(
    initial_request: Any,
    request_method: Callable,
    pages_limit: int = 0,
    per_page_limit: Optional[int] = DEFAULT_PER_PAGE_LIMIT,
) -> List[Any]:
    """
    Get pages for specific request.

    :param initial_request: request supports pagination
    :param request_method: function to perform request
    :param pages_limit: max number of pages to return. default - 0 unlimited
    :param per_page_limit: Optional int: amount of records per one page. default is None, determined by server

    :return: List of responses
    """
    pages: List[Any] = []
    pagination = PageRequest(limit=per_page_limit)

    while pagination and (len(pages) < pages_limit or pages_limit == 0):
        request = initial_request.__class__()
        request.CopyFrom(initial_request)
        request.pagination.CopyFrom(pagination)

        resp = request_method(request)

        pages.append(resp)

        pagination = None

        if resp.pagination.next_key:
            pagination = PageRequest(limit=per_page_limit, key=resp.pagination.next_key)
    return pages



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from cosmos.distribution.v1beta1 import distribution_pb2 as _distribution_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DelegatorWithdrawInfo(_message.Message):
    __slots__ = ("delegator_address", "withdraw_address")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    WITHDRAW_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    withdraw_address: str
    def __init__(self, delegator_address: _Optional[str] = ..., withdraw_address: _Optional[str] = ...) -> None: ...

class ValidatorOutstandingRewardsRecord(_message.Message):
    __slots__ = ("validator_address", "outstanding_rewards")
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    OUTSTANDING_REWARDS_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    outstanding_rewards: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    def __init__(self, validator_address: _Optional[str] = ..., outstanding_rewards: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ...) -> None: ...

class ValidatorAccumulatedCommissionRecord(_message.Message):
    __slots__ = ("validator_address", "accumulated")
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ACCUMULATED_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    accumulated: _distribution_pb2.ValidatorAccumulatedCommission
    def __init__(self, validator_address: _Optional[str] = ..., accumulated: _Optional[_Union[_distribution_pb2.ValidatorAccumulatedCommission, _Mapping]] = ...) -> None: ...

class ValidatorHistoricalRewardsRecord(_message.Message):
    __slots__ = ("validator_address", "period", "rewards")
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    period: int
    rewards: _distribution_pb2.ValidatorHistoricalRewards
    def __init__(self, validator_address: _Optional[str] = ..., period: _Optional[int] = ..., rewards: _Optional[_Union[_distribution_pb2.ValidatorHistoricalRewards, _Mapping]] = ...) -> None: ...

class ValidatorCurrentRewardsRecord(_message.Message):
    __slots__ = ("validator_address", "rewards")
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    rewards: _distribution_pb2.ValidatorCurrentRewards
    def __init__(self, validator_address: _Optional[str] = ..., rewards: _Optional[_Union[_distribution_pb2.ValidatorCurrentRewards, _Mapping]] = ...) -> None: ...

class DelegatorStartingInfoRecord(_message.Message):
    __slots__ = ("delegator_address", "validator_address", "starting_info")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STARTING_INFO_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_address: str
    starting_info: _distribution_pb2.DelegatorStartingInfo
    def __init__(self, delegator_address: _Optional[str] = ..., validator_address: _Optional[str] = ..., starting_info: _Optional[_Union[_distribution_pb2.DelegatorStartingInfo, _Mapping]] = ...) -> None: ...

class ValidatorSlashEventRecord(_message.Message):
    __slots__ = ("validator_address", "height", "period", "validator_slash_event")
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SLASH_EVENT_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    height: int
    period: int
    validator_slash_event: _distribution_pb2.ValidatorSlashEvent
    def __init__(self, validator_address: _Optional[str] = ..., height: _Optional[int] = ..., period: _Optional[int] = ..., validator_slash_event: _Optional[_Union[_distribution_pb2.ValidatorSlashEvent, _Mapping]] = ...) -> None: ...

class GenesisState(_message.Message):
    __slots__ = ("params", "fee_pool", "delegator_withdraw_infos", "previous_proposer", "outstanding_rewards", "validator_accumulated_commissions", "validator_historical_rewards", "validator_current_rewards", "delegator_starting_infos", "validator_slash_events")
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    FEE_POOL_FIELD_NUMBER: _ClassVar[int]
    DELEGATOR_WITHDRAW_INFOS_FIELD_NUMBER: _ClassVar[int]
    PREVIOUS_PROPOSER_FIELD_NUMBER: _ClassVar[int]
    OUTSTANDING_REWARDS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ACCUMULATED_COMMISSIONS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_HISTORICAL_REWARDS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_CURRENT_REWARDS_FIELD_NUMBER: _ClassVar[int]
    DELEGATOR_STARTING_INFOS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SLASH_EVENTS_FIELD_NUMBER: _ClassVar[int]
    params: _distribution_pb2.Params
    fee_pool: _distribution_pb2.FeePool
    delegator_withdraw_infos: _containers.RepeatedCompositeFieldContainer[DelegatorWithdrawInfo]
    previous_proposer: str
    outstanding_rewards: _containers.RepeatedCompositeFieldContainer[ValidatorOutstandingRewardsRecord]
    validator_accumulated_commissions: _containers.RepeatedCompositeFieldContainer[ValidatorAccumulatedCommissionRecord]
    validator_historical_rewards: _containers.RepeatedCompositeFieldContainer[ValidatorHistoricalRewardsRecord]
    validator_current_rewards: _containers.RepeatedCompositeFieldContainer[ValidatorCurrentRewardsRecord]
    delegator_starting_infos: _containers.RepeatedCompositeFieldContainer[DelegatorStartingInfoRecord]
    validator_slash_events: _containers.RepeatedCompositeFieldContainer[ValidatorSlashEventRecord]
    def __init__(self, params: _Optional[_Union[_distribution_pb2.Params, _Mapping]] = ..., fee_pool: _Optional[_Union[_distribution_pb2.FeePool, _Mapping]] = ..., delegator_withdraw_infos: _Optional[_Iterable[_Union[DelegatorWithdrawInfo, _Mapping]]] = ..., previous_proposer: _Optional[str] = ..., outstanding_rewards: _Optional[_Iterable[_Union[ValidatorOutstandingRewardsRecord, _Mapping]]] = ..., validator_accumulated_commissions: _Optional[_Iterable[_Union[ValidatorAccumulatedCommissionRecord, _Mapping]]] = ..., validator_historical_rewards: _Optional[_Iterable[_Union[ValidatorHistoricalRewardsRecord, _Mapping]]] = ..., validator_current_rewards: _Optional[_Iterable[_Union[ValidatorCurrentRewardsRecord, _Mapping]]] = ..., delegator_starting_infos: _Optional[_Iterable[_Union[DelegatorStartingInfoRecord, _Mapping]]] = ..., validator_slash_events: _Optional[_Iterable[_Union[ValidatorSlashEventRecord, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/types/v1beta2/params.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/types/v1beta2/params.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cometbft.types.v1beta1 import params_pb2 as cometbft_dot_types_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cometbft/types/v1beta2/params.proto\x12\x16\x63ometbft.types.v1beta2\x1a\x14gogoproto/gogo.proto\x1a#cometbft/types/v1beta1/params.proto\"\xf3\x01\n\x0f\x43onsensusParams\x12\x32\n\x05\x62lock\x18\x01 \x01(\x0b\x32#.cometbft.types.v1beta2.BlockParams\x12\x38\n\x08\x65vidence\x18\x02 \x01(\x0b\x32&.cometbft.types.v1beta1.EvidenceParams\x12:\n\tvalidator\x18\x03 \x01(\x0b\x32\'.cometbft.types.v1beta1.ValidatorParams\x12\x36\n\x07version\x18\x04 \x01(\x0b\x32%.cometbft.types.v1beta1.VersionParams\"7\n\x0b\x42lockParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x03\x12\x0f\n\x07max_gas\x18\x02 \x01(\x03J\x04\x08\x03\x10\x04\x42=Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta2\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1beta2.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta2\250\342\036\001'
  _globals['_CONSENSUSPARAMS']._serialized_start=123
  _globals['_CONSENSUSPARAMS']._serialized_end=366
  _globals['_BLOCKPARAMS']._serialized_start=368
  _globals['_BLOCKPARAMS']._serialized_end=423
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/consensus/v2/wal.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/consensus/v2/wal.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.consensus.v2 import types_pb2 as cometbft_dot_consensus_dot_v2_dot_types__pb2
from cometbft.types.v2 import events_pb2 as cometbft_dot_types_dot_v2_dot_events__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/consensus/v2/wal.proto\x12\x15\x63ometbft.consensus.v2\x1a!cometbft/consensus/v2/types.proto\x1a\x1e\x63ometbft/types/v2/events.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x95\x01\n\x07MsgInfo\x12\x31\n\x03msg\x18\x01 \x01(\x0b\x32\x1e.cometbft.consensus.v2.MessageB\x04\xc8\xde\x1f\x00\x12\x1b\n\x07peer_id\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06PeerID\x12:\n\x0creceive_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x01\x90\xdf\x1f\x01\"q\n\x0bTimeoutInfo\x12\x35\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12\x0c\n\x04step\x18\x04 \x01(\r\"\x1b\n\tEndHeight\x12\x0e\n\x06height\x18\x01 \x01(\x03\"\x85\x02\n\nWALMessage\x12H\n\x16\x65vent_data_round_state\x18\x01 \x01(\x0b\x32&.cometbft.types.v2.EventDataRoundStateH\x00\x12\x32\n\x08msg_info\x18\x02 \x01(\x0b\x32\x1e.cometbft.consensus.v2.MsgInfoH\x00\x12:\n\x0ctimeout_info\x18\x03 \x01(\x0b\x32\".cometbft.consensus.v2.TimeoutInfoH\x00\x12\x36\n\nend_height\x18\x04 \x01(\x0b\x32 .cometbft.consensus.v2.EndHeightH\x00\x42\x05\n\x03sum\"u\n\x0fTimedWALMessage\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12.\n\x03msg\x18\x02 \x01(\x0b\x32!.cometbft.consensus.v2.WALMessageB8Z6github.com/cometbft/cometbft/api/cometbft/consensus/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.consensus.v2.wal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/cometbft/cometbft/api/cometbft/consensus/v2'
  _globals['_MSGINFO'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['msg']._serialized_options = b'\310\336\037\000'
  _globals['_MSGINFO'].fields_by_name['peer_id']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['peer_id']._serialized_options = b'\342\336\037\006PeerID'
  _globals['_MSGINFO'].fields_by_name['receive_time']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['receive_time']._serialized_options = b'\310\336\037\001\220\337\037\001'
  _globals['_TIMEOUTINFO'].fields_by_name['duration']._loaded_options = None
  _globals['_TIMEOUTINFO'].fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_TIMEDWALMESSAGE'].fields_by_name['time']._loaded_options = None
  _globals['_TIMEDWALMESSAGE'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_MSGINFO']._serialized_start=213
  _globals['_MSGINFO']._serialized_end=362
  _globals['_TIMEOUTINFO']._serialized_start=364
  _globals['_TIMEOUTINFO']._serialized_end=477
  _globals['_ENDHEIGHT']._serialized_start=479
  _globals['_ENDHEIGHT']._serialized_end=506
  _globals['_WALMESSAGE']._serialized_start=509
  _globals['_WALMESSAGE']._serialized_end=770
  _globals['_TIMEDWALMESSAGE']._serialized_start=772
  _globals['_TIMEDWALMESSAGE']._serialized_end=889
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SnapshotItem(_message.Message):
    __slots__ = ("store", "iavl")
    STORE_FIELD_NUMBER: _ClassVar[int]
    IAVL_FIELD_NUMBER: _ClassVar[int]
    store: SnapshotStoreItem
    iavl: SnapshotIAVLItem
    def __init__(self, store: _Optional[_Union[SnapshotStoreItem, _Mapping]] = ..., iavl: _Optional[_Union[SnapshotIAVLItem, _Mapping]] = ...) -> None: ...

class SnapshotStoreItem(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class SnapshotIAVLItem(_message.Message):
    __slots__ = ("key", "value", "version", "height")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    value: bytes
    version: int
    height: int
    def __init__(self, key: _Optional[bytes] = ..., value: _Optional[bytes] = ..., version: _Optional[int] = ..., height: _Optional[int] = ...) -> None: ...



import json
from typing import Any


class JSONEncoder(json.JSONEncoder):
    """JSONEncoder subclass that encode basic python objects."""  # noqa: D401

    def default(self, o: Any) -> Any:
        """Default json encode."""  # noqa: D401
        if not hasattr(o, "__json__"):
            return super().default(o)
        if callable(o.__json__):
            return o.__json__()
        return o.__json__


def json_encode(data, **kwargs):
    """Json encode."""
    return JSONEncoder(**kwargs).encode(data)



from cometbft.services.block_results.v1 import block_results_pb2 as _block_results_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



from amino import amino_pb2 as _amino_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from neurion.fusion import params_pb2 as _params_pb2
from neurion.fusion import task_pb2 as _task_pb2
from neurion.fusion import creator_application_pb2 as _creator_application_pb2
from neurion.fusion import proposed_model_pb2 as _proposed_model_pb2
from neurion.fusion import validation_task_pb2 as _validation_task_pb2
from neurion.fusion import dispute_validation_task_pb2 as _dispute_validation_task_pb2
from neurion.fusion import error_code_pb2 as _error_code_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryGetTaskRequest(_message.Message):
    __slots__ = ("task_id",)
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    task_id: int
    def __init__(self, task_id: _Optional[int] = ...) -> None: ...

class QueryGetTaskResponse(_message.Message):
    __slots__ = ("task",)
    TASK_FIELD_NUMBER: _ClassVar[int]
    task: _task_pb2.Task
    def __init__(self, task: _Optional[_Union[_task_pb2.Task, _Mapping]] = ...) -> None: ...

class QueryGetTaskRewardRequest(_message.Message):
    __slots__ = ("task_id", "user")
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    task_id: int
    user: str
    def __init__(self, task_id: _Optional[int] = ..., user: _Optional[str] = ...) -> None: ...

class QueryGetTaskRewardResponse(_message.Message):
    __slots__ = ("reward",)
    REWARD_FIELD_NUMBER: _ClassVar[int]
    reward: int
    def __init__(self, reward: _Optional[int] = ...) -> None: ...

class QueryGetCreatorApplicationsRequest(_message.Message):
    __slots__ = ("creator",)
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    creator: str
    def __init__(self, creator: _Optional[str] = ...) -> None: ...

class QueryGetCreatorApplicationsResponse(_message.Message):
    __slots__ = ("applicants",)
    APPLICANTS_FIELD_NUMBER: _ClassVar[int]
    applicants: _containers.RepeatedCompositeFieldContainer[_creator_application_pb2.CreatorApplication]
    def __init__(self, applicants: _Optional[_Iterable[_Union[_creator_application_pb2.CreatorApplication, _Mapping]]] = ...) -> None: ...

class QueryGetPendingCreatorApplicationsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGetPendingCreatorApplicationsResponse(_message.Message):
    __slots__ = ("applicants",)
    APPLICANTS_FIELD_NUMBER: _ClassVar[int]
    applicants: _containers.RepeatedCompositeFieldContainer[_creator_application_pb2.CreatorApplication]
    def __init__(self, applicants: _Optional[_Iterable[_Union[_creator_application_pb2.CreatorApplication, _Mapping]]] = ...) -> None: ...

class QueryGetModelsByRoundRequest(_message.Message):
    __slots__ = ("task_id", "round")
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    task_id: int
    round: int
    def __init__(self, task_id: _Optional[int] = ..., round: _Optional[int] = ...) -> None: ...

class QueryGetModelsByRoundResponse(_message.Message):
    __slots__ = ("models",)
    MODELS_FIELD_NUMBER: _ClassVar[int]
    models: _containers.RepeatedCompositeFieldContainer[_proposed_model_pb2.ProposedModel]
    def __init__(self, models: _Optional[_Iterable[_Union[_proposed_model_pb2.ProposedModel, _Mapping]]] = ...) -> None: ...

class QueryGetTaskStakeRequest(_message.Message):
    __slots__ = ("task_id", "user")
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    task_id: int
    user: str
    def __init__(self, task_id: _Optional[int] = ..., user: _Optional[str] = ...) -> None: ...

class QueryGetTaskStakeResponse(_message.Message):
    __slots__ = ("stake",)
    STAKE_FIELD_NUMBER: _ClassVar[int]
    stake: int
    def __init__(self, stake: _Optional[int] = ...) -> None: ...

class QueryGetValidationTaskRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryGetValidationTaskResponse(_message.Message):
    __slots__ = ("validation_task",)
    VALIDATION_TASK_FIELD_NUMBER: _ClassVar[int]
    validation_task: _validation_task_pb2.ValidationTask
    def __init__(self, validation_task: _Optional[_Union[_validation_task_pb2.ValidationTask, _Mapping]] = ...) -> None: ...

class QueryCanTriggerTestingForRoundRequest(_message.Message):
    __slots__ = ("user", "task_id", "round")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    round: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ..., round: _Optional[int] = ...) -> None: ...

class QueryCanTriggerTestingForRoundResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanStartNewRoundRequest(_message.Message):
    __slots__ = ("user", "task_id", "round")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    round: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ..., round: _Optional[int] = ...) -> None: ...

class QueryCanStartNewRoundResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanRegisterAsProposerRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanRegisterAsProposerResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanRegisterAsValidatorRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanRegisterAsValidatorResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryIsProposerRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryIsProposerResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryIsValidatorRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryIsValidatorResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanProposeModelRequest(_message.Message):
    __slots__ = ("user", "task_id", "round")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    round: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ..., round: _Optional[int] = ...) -> None: ...

class QueryCanProposeModelResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryCanRequestValidationTaskRequest(_message.Message):
    __slots__ = ("user", "task_id", "round")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    round: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ..., round: _Optional[int] = ...) -> None: ...

class QueryCanRequestValidationTaskResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryGetPendingValidationTasksRequest(_message.Message):
    __slots__ = ("user", "task_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    user: str
    task_id: int
    def __init__(self, user: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryGetPendingValidationTasksResponse(_message.Message):
    __slots__ = ("validation_tasks",)
    VALIDATION_TASKS_FIELD_NUMBER: _ClassVar[int]
    validation_tasks: _containers.RepeatedCompositeFieldContainer[_validation_task_pb2.ValidationTask]
    def __init__(self, validation_tasks: _Optional[_Iterable[_Union[_validation_task_pb2.ValidationTask, _Mapping]]] = ...) -> None: ...

class QueryCanTerminateRequest(_message.Message):
    __slots__ = ("creator", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class QueryCanTerminateResponse(_message.Message):
    __slots__ = ("result", "reason")
    RESULT_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    result: bool
    reason: _error_code_pb2.ErrorCode
    def __init__(self, result: bool = ..., reason: _Optional[_Union[_error_code_pb2.ErrorCode, str]] = ...) -> None: ...

class QueryGetScoreDisputeFromUserRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryGetScoreDisputeFromUserResponse(_message.Message):
    __slots__ = ("dispute_validation_tasks",)
    DISPUTE_VALIDATION_TASKS_FIELD_NUMBER: _ClassVar[int]
    dispute_validation_tasks: _containers.RepeatedCompositeFieldContainer[_dispute_validation_task_pb2.DisputeValidationTask]
    def __init__(self, dispute_validation_tasks: _Optional[_Iterable[_Union[_dispute_validation_task_pb2.DisputeValidationTask, _Mapping]]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Submission(_message.Message):
    __slots__ = ("id", "creator", "task_id", "result", "metainfo", "created_timestamp", "score", "scorer", "scored", "scored_timestamp", "encrypted_proof_of_ownership", "revealed_proof_of_ownership", "is_final", "is_disputed", "dispute_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    METAINFO_FIELD_NUMBER: _ClassVar[int]
    CREATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    SCORER_FIELD_NUMBER: _ClassVar[int]
    SCORED_FIELD_NUMBER: _ClassVar[int]
    SCORED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_PROOF_OF_OWNERSHIP_FIELD_NUMBER: _ClassVar[int]
    REVEALED_PROOF_OF_OWNERSHIP_FIELD_NUMBER: _ClassVar[int]
    IS_FINAL_FIELD_NUMBER: _ClassVar[int]
    IS_DISPUTED_FIELD_NUMBER: _ClassVar[int]
    DISPUTE_ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    creator: str
    task_id: int
    result: str
    metainfo: str
    created_timestamp: int
    score: str
    scorer: str
    scored: bool
    scored_timestamp: int
    encrypted_proof_of_ownership: str
    revealed_proof_of_ownership: str
    is_final: bool
    is_disputed: bool
    dispute_id: int
    def __init__(self, id: _Optional[int] = ..., creator: _Optional[str] = ..., task_id: _Optional[int] = ..., result: _Optional[str] = ..., metainfo: _Optional[str] = ..., created_timestamp: _Optional[int] = ..., score: _Optional[str] = ..., scorer: _Optional[str] = ..., scored: bool = ..., scored_timestamp: _Optional[int] = ..., encrypted_proof_of_ownership: _Optional[str] = ..., revealed_proof_of_ownership: _Optional[str] = ..., is_final: bool = ..., is_disputed: bool = ..., dispute_id: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/applications/interchain_accounts/v1/packet.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/applications/interchain_accounts/v1/packet.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4ibc/applications/interchain_accounts/v1/packet.proto\x12\'ibc.applications.interchain_accounts.v1\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\"v\n\x1bInterchainAccountPacketData\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.ibc.applications.interchain_accounts.v1.Type\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0c\n\x04memo\x18\x03 \x01(\t\"2\n\x08\x43osmosTx\x12&\n\x08messages\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any*X\n\x04Type\x12%\n\x10TYPE_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12#\n\x0fTYPE_EXECUTE_TX\x10\x01\x1a\x0e\x8a\x9d \nEXECUTE_TX\x1a\x04\x88\xa3\x1e\x00\x42GZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.v1.packet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/types'
  _globals['_TYPE']._loaded_options = None
  _globals['_TYPE']._serialized_options = b'\210\243\036\000'
  _globals['_TYPE'].values_by_name["TYPE_UNSPECIFIED"]._loaded_options = None
  _globals['_TYPE'].values_by_name["TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \013UNSPECIFIED'
  _globals['_TYPE'].values_by_name["TYPE_EXECUTE_TX"]._loaded_options = None
  _globals['_TYPE'].values_by_name["TYPE_EXECUTE_TX"]._serialized_options = b'\212\235 \nEXECUTE_TX'
  _globals['_TYPE']._serialized_start=318
  _globals['_TYPE']._serialized_end=406
  _globals['_INTERCHAINACCOUNTPACKETDATA']._serialized_start=146
  _globals['_INTERCHAINACCOUNTPACKETDATA']._serialized_end=264
  _globals['_COSMOSTX']._serialized_start=266
  _globals['_COSMOSTX']._serialized_end=316
# @@protoc_insertion_point(module_scope)



from cometbft.rpc.grpc.v1beta1 import types_pb2 as _types_pb2
from cometbft.abci.v1beta3 import types_pb2 as _types_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ResponseBroadcastTx(_message.Message):
    __slots__ = ("check_tx", "tx_result")
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    TX_RESULT_FIELD_NUMBER: _ClassVar[int]
    check_tx: _types_pb2_1.ResponseCheckTx
    tx_result: _types_pb2_1.ExecTxResult
    def __init__(self, check_tx: _Optional[_Union[_types_pb2_1.ResponseCheckTx, _Mapping]] = ..., tx_result: _Optional[_Union[_types_pb2_1.ExecTxResult, _Mapping]] = ...) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ClientState(_message.Message):
    __slots__ = ("chain_id", "height")
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    chain_id: str
    height: _client_pb2.Height
    def __init__(self, chain_id: _Optional[str] = ..., height: _Optional[_Union[_client_pb2.Height, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/distribution/v1beta1/distribution.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/distribution/v1beta1/distribution.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.cosmos/distribution/v1beta1/distribution.proto\x12\x1b\x63osmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x8a\x03\n\x06Params\x12]\n\rcommunity_tax\x18\x01 \x01(\tBF\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x14yaml:\"community_tax\"\x12k\n\x14\x62\x61se_proposer_reward\x18\x02 \x01(\tBM\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x1byaml:\"base_proposer_reward\"\x12m\n\x15\x62onus_proposer_reward\x18\x03 \x01(\tBN\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x1cyaml:\"bonus_proposer_reward\"\x12?\n\x15withdraw_addr_enabled\x18\x04 \x01(\x08\x42 \xf2\xde\x1f\x1cyaml:\"withdraw_addr_enabled\":\x04\x98\xa0\x1f\x00\"\xe8\x01\n\x1aValidatorHistoricalRewards\x12\x94\x01\n\x17\x63umulative_reward_ratio\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinBU\xc8\xde\x1f\x00\xf2\xde\x1f\x1eyaml:\"cumulative_reward_ratio\"\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\x12\x33\n\x0freference_count\x18\x02 \x01(\rB\x1a\xf2\xde\x1f\x16yaml:\"reference_count\"\"\x8d\x01\n\x17ValidatorCurrentRewards\x12\x62\n\x07rewards\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB3\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\x12\x0e\n\x06period\x18\x02 \x01(\x04\"\x87\x01\n\x1eValidatorAccumulatedCommission\x12\x65\n\ncommission\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB3\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\"\x93\x01\n\x1bValidatorOutstandingRewards\x12t\n\x07rewards\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinBE\xc8\xde\x1f\x00\xf2\xde\x1f\x0eyaml:\"rewards\"\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\"\x8e\x01\n\x13ValidatorSlashEvent\x12\x35\n\x10validator_period\x18\x01 \x01(\x04\x42\x1b\xf2\xde\x1f\x17yaml:\"validator_period\"\x12@\n\x08\x66raction\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\x95\x01\n\x14ValidatorSlashEvents\x12w\n\x16validator_slash_events\x18\x01 \x03(\x0b\x32\x30.cosmos.distribution.v1beta1.ValidatorSlashEventB%\xc8\xde\x1f\x00\xf2\xde\x1f\x1dyaml:\"validator_slash_events\":\x04\x98\xa0\x1f\x00\"\x8e\x01\n\x07\x46\x65\x65Pool\x12\x82\x01\n\x0e\x63ommunity_pool\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinBL\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:\"community_pool\"\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\"\xbe\x01\n\x1a\x43ommunityPoolSpendProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\trecipient\x18\x03 \x01(\t\x12[\n\x06\x61mount\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xda\x01\n\x15\x44\x65legatorStartingInfo\x12\x33\n\x0fprevious_period\x18\x01 \x01(\x04\x42\x1a\xf2\xde\x1f\x16yaml:\"previous_period\"\x12M\n\x05stake\x18\x02 \x01(\tB>\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x0cyaml:\"stake\"\x12=\n\x06height\x18\x03 \x01(\x04\x42-\xea\xde\x1f\x0f\x63reation_height\xf2\xde\x1f\x16yaml:\"creation_height\"\"\xc1\x01\n\x19\x44\x65legationDelegatorReward\x12\x37\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\"\x12\x61\n\x06reward\x18\x02 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB3\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x01\"\xf0\x01\n%CommunityPoolSpendProposalWithDeposit\x12\x1f\n\x05title\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"title\"\x12+\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"description\"\x12\'\n\trecipient\x18\x03 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"recipient\"\x12!\n\x06\x61mount\x18\x04 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"amount\"\x12#\n\x07\x64\x65posit\x18\x05 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"deposit\":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x01\x42\x37Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.distribution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\250\342\036\001'
  _globals['_PARAMS'].fields_by_name['community_tax']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['community_tax']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\024yaml:\"community_tax\"'
  _globals['_PARAMS'].fields_by_name['base_proposer_reward']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['base_proposer_reward']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\033yaml:\"base_proposer_reward\"'
  _globals['_PARAMS'].fields_by_name['bonus_proposer_reward']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['bonus_proposer_reward']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\034yaml:\"bonus_proposer_reward\"'
  _globals['_PARAMS'].fields_by_name['withdraw_addr_enabled']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['withdraw_addr_enabled']._serialized_options = b'\362\336\037\034yaml:\"withdraw_addr_enabled\"'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\230\240\037\000'
  _globals['_VALIDATORHISTORICALREWARDS'].fields_by_name['cumulative_reward_ratio']._loaded_options = None
  _globals['_VALIDATORHISTORICALREWARDS'].fields_by_name['cumulative_reward_ratio']._serialized_options = b'\310\336\037\000\362\336\037\036yaml:\"cumulative_reward_ratio\"\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins'
  _globals['_VALIDATORHISTORICALREWARDS'].fields_by_name['reference_count']._loaded_options = None
  _globals['_VALIDATORHISTORICALREWARDS'].fields_by_name['reference_count']._serialized_options = b'\362\336\037\026yaml:\"reference_count\"'
  _globals['_VALIDATORCURRENTREWARDS'].fields_by_name['rewards']._loaded_options = None
  _globals['_VALIDATORCURRENTREWARDS'].fields_by_name['rewards']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins'
  _globals['_VALIDATORACCUMULATEDCOMMISSION'].fields_by_name['commission']._loaded_options = None
  _globals['_VALIDATORACCUMULATEDCOMMISSION'].fields_by_name['commission']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins'
  _globals['_VALIDATOROUTSTANDINGREWARDS'].fields_by_name['rewards']._loaded_options = None
  _globals['_VALIDATOROUTSTANDINGREWARDS'].fields_by_name['rewards']._serialized_options = b'\310\336\037\000\362\336\037\016yaml:\"rewards\"\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins'
  _globals['_VALIDATORSLASHEVENT'].fields_by_name['validator_period']._loaded_options = None
  _globals['_VALIDATORSLASHEVENT'].fields_by_name['validator_period']._serialized_options = b'\362\336\037\027yaml:\"validator_period\"'
  _globals['_VALIDATORSLASHEVENT'].fields_by_name['fraction']._loaded_options = None
  _globals['_VALIDATORSLASHEVENT'].fields_by_name['fraction']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _globals['_VALIDATORSLASHEVENTS'].fields_by_name['validator_slash_events']._loaded_options = None
  _globals['_VALIDATORSLASHEVENTS'].fields_by_name['validator_slash_events']._serialized_options = b'\310\336\037\000\362\336\037\035yaml:\"validator_slash_events\"'
  _globals['_VALIDATORSLASHEVENTS']._loaded_options = None
  _globals['_VALIDATORSLASHEVENTS']._serialized_options = b'\230\240\037\000'
  _globals['_FEEPOOL'].fields_by_name['community_pool']._loaded_options = None
  _globals['_FEEPOOL'].fields_by_name['community_pool']._serialized_options = b'\310\336\037\000\362\336\037\025yaml:\"community_pool\"\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins'
  _globals['_COMMUNITYPOOLSPENDPROPOSAL'].fields_by_name['amount']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSAL'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_COMMUNITYPOOLSPENDPROPOSAL']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSAL']._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _globals['_DELEGATORSTARTINGINFO'].fields_by_name['previous_period']._loaded_options = None
  _globals['_DELEGATORSTARTINGINFO'].fields_by_name['previous_period']._serialized_options = b'\362\336\037\026yaml:\"previous_period\"'
  _globals['_DELEGATORSTARTINGINFO'].fields_by_name['stake']._loaded_options = None
  _globals['_DELEGATORSTARTINGINFO'].fields_by_name['stake']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\014yaml:\"stake\"'
  _globals['_DELEGATORSTARTINGINFO'].fields_by_name['height']._loaded_options = None
  _globals['_DELEGATORSTARTINGINFO'].fields_by_name['height']._serialized_options = b'\352\336\037\017creation_height\362\336\037\026yaml:\"creation_height\"'
  _globals['_DELEGATIONDELEGATORREWARD'].fields_by_name['validator_address']._loaded_options = None
  _globals['_DELEGATIONDELEGATORREWARD'].fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _globals['_DELEGATIONDELEGATORREWARD'].fields_by_name['reward']._loaded_options = None
  _globals['_DELEGATIONDELEGATORREWARD'].fields_by_name['reward']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins'
  _globals['_DELEGATIONDELEGATORREWARD']._loaded_options = None
  _globals['_DELEGATIONDELEGATORREWARD']._serialized_options = b'\210\240\037\000\230\240\037\001'
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT'].fields_by_name['title']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT'].fields_by_name['title']._serialized_options = b'\362\336\037\014yaml:\"title\"'
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT'].fields_by_name['description']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT'].fields_by_name['description']._serialized_options = b'\362\336\037\022yaml:\"description\"'
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT'].fields_by_name['recipient']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT'].fields_by_name['recipient']._serialized_options = b'\362\336\037\020yaml:\"recipient\"'
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT'].fields_by_name['amount']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT'].fields_by_name['amount']._serialized_options = b'\362\336\037\ryaml:\"amount\"'
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT'].fields_by_name['deposit']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT'].fields_by_name['deposit']._serialized_options = b'\362\336\037\016yaml:\"deposit\"'
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT']._loaded_options = None
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT']._serialized_options = b'\210\240\037\000\230\240\037\001'
  _globals['_PARAMS']._serialized_start=134
  _globals['_PARAMS']._serialized_end=528
  _globals['_VALIDATORHISTORICALREWARDS']._serialized_start=531
  _globals['_VALIDATORHISTORICALREWARDS']._serialized_end=763
  _globals['_VALIDATORCURRENTREWARDS']._serialized_start=766
  _globals['_VALIDATORCURRENTREWARDS']._serialized_end=907
  _globals['_VALIDATORACCUMULATEDCOMMISSION']._serialized_start=910
  _globals['_VALIDATORACCUMULATEDCOMMISSION']._serialized_end=1045
  _globals['_VALIDATOROUTSTANDINGREWARDS']._serialized_start=1048
  _globals['_VALIDATOROUTSTANDINGREWARDS']._serialized_end=1195
  _globals['_VALIDATORSLASHEVENT']._serialized_start=1198
  _globals['_VALIDATORSLASHEVENT']._serialized_end=1340
  _globals['_VALIDATORSLASHEVENTS']._serialized_start=1343
  _globals['_VALIDATORSLASHEVENTS']._serialized_end=1492
  _globals['_FEEPOOL']._serialized_start=1495
  _globals['_FEEPOOL']._serialized_end=1637
  _globals['_COMMUNITYPOOLSPENDPROPOSAL']._serialized_start=1640
  _globals['_COMMUNITYPOOLSPENDPROPOSAL']._serialized_end=1830
  _globals['_DELEGATORSTARTINGINFO']._serialized_start=1833
  _globals['_DELEGATORSTARTINGINFO']._serialized_end=2051
  _globals['_DELEGATIONDELEGATORREWARD']._serialized_start=2054
  _globals['_DELEGATIONDELEGATORREWARD']._serialized_end=2247
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT']._serialized_start=2250
  _globals['_COMMUNITYPOOLSPENDPROPOSALWITHDEPOSIT']._serialized_end=2490
# @@protoc_insertion_point(module_scope)



from amino import amino_pb2 as _amino_pb2
from cosmos.msg.v1 import msg_pb2 as _msg_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from neurion.ganglion import ion_pb2 as _ion_pb2
from neurion.ganglion import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgUpdateParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _params_pb2.Params
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class MsgUpdateParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRegisterIon(_message.Message):
    __slots__ = ("creator", "capacities", "stake", "endpoints", "description", "input_schema", "output_schema", "fee_per_thousand_calls", "allowed_pathway_owners", "private")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    CAPACITIES_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    ENDPOINTS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    INPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    FEE_PER_THOUSAND_CALLS_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_PATHWAY_OWNERS_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_FIELD_NUMBER: _ClassVar[int]
    creator: str
    capacities: _containers.RepeatedScalarFieldContainer[str]
    stake: int
    endpoints: _containers.RepeatedScalarFieldContainer[str]
    description: str
    input_schema: str
    output_schema: str
    fee_per_thousand_calls: int
    allowed_pathway_owners: _containers.RepeatedScalarFieldContainer[str]
    private: bool
    def __init__(self, creator: _Optional[str] = ..., capacities: _Optional[_Iterable[str]] = ..., stake: _Optional[int] = ..., endpoints: _Optional[_Iterable[str]] = ..., description: _Optional[str] = ..., input_schema: _Optional[str] = ..., output_schema: _Optional[str] = ..., fee_per_thousand_calls: _Optional[int] = ..., allowed_pathway_owners: _Optional[_Iterable[str]] = ..., private: bool = ...) -> None: ...

class MsgRegisterIonResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgReportUnavailableIon(_message.Message):
    __slots__ = ("creator", "ion_address")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ION_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    creator: str
    ion_address: str
    def __init__(self, creator: _Optional[str] = ..., ion_address: _Optional[str] = ...) -> None: ...

class MsgReportUnavailableIonResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUnreportUnavailableIon(_message.Message):
    __slots__ = ("creator", "ion_address")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ION_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    creator: str
    ion_address: str
    def __init__(self, creator: _Optional[str] = ..., ion_address: _Optional[str] = ...) -> None: ...

class MsgUnreportUnavailableIonResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgAddValidator(_message.Message):
    __slots__ = ("creator", "validator_address")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    creator: str
    validator_address: str
    def __init__(self, creator: _Optional[str] = ..., validator_address: _Optional[str] = ...) -> None: ...

class MsgAddValidatorResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRemoveValidator(_message.Message):
    __slots__ = ("creator", "validator_address")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    creator: str
    validator_address: str
    def __init__(self, creator: _Optional[str] = ..., validator_address: _Optional[str] = ...) -> None: ...

class MsgRemoveValidatorResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgValidateAvailability(_message.Message):
    __slots__ = ("creator", "ion_address", "available")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ION_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    creator: str
    ion_address: str
    available: bool
    def __init__(self, creator: _Optional[str] = ..., ion_address: _Optional[str] = ..., available: bool = ...) -> None: ...

class MsgValidateAvailabilityResponse(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class MsgRegisterPathway(_message.Message):
    __slots__ = ("creator", "name", "description", "is_public", "ions", "field_maps_base64")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    IONS_FIELD_NUMBER: _ClassVar[int]
    FIELD_MAPS_BASE64_FIELD_NUMBER: _ClassVar[int]
    creator: str
    name: str
    description: str
    is_public: bool
    ions: _containers.RepeatedScalarFieldContainer[str]
    field_maps_base64: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, creator: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., is_public: bool = ..., ions: _Optional[_Iterable[str]] = ..., field_maps_base64: _Optional[_Iterable[str]] = ...) -> None: ...

class MsgRegisterPathwayResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgStakePathway(_message.Message):
    __slots__ = ("creator", "id", "amount")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    creator: str
    id: int
    amount: int
    def __init__(self, creator: _Optional[str] = ..., id: _Optional[int] = ..., amount: _Optional[int] = ...) -> None: ...

class MsgStakePathwayResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRefundPathwayStake(_message.Message):
    __slots__ = ("creator", "id", "user", "num_calls")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    NUM_CALLS_FIELD_NUMBER: _ClassVar[int]
    creator: str
    id: int
    user: str
    num_calls: int
    def __init__(self, creator: _Optional[str] = ..., id: _Optional[int] = ..., user: _Optional[str] = ..., num_calls: _Optional[int] = ...) -> None: ...

class MsgRefundPathwayStakeResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgInitUnstakePathway(_message.Message):
    __slots__ = ("creator", "id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    id: int
    def __init__(self, creator: _Optional[str] = ..., id: _Optional[int] = ...) -> None: ...

class MsgInitUnstakePathwayResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgClaimProtocolFee(_message.Message):
    __slots__ = ("creator",)
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    creator: str
    def __init__(self, creator: _Optional[str] = ...) -> None: ...

class MsgClaimProtocolFeeResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSettlePathwayStake(_message.Message):
    __slots__ = ("creator", "id", "user", "num_calls")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    NUM_CALLS_FIELD_NUMBER: _ClassVar[int]
    creator: str
    id: int
    user: str
    num_calls: int
    def __init__(self, creator: _Optional[str] = ..., id: _Optional[int] = ..., user: _Optional[str] = ..., num_calls: _Optional[int] = ...) -> None: ...

class MsgSettlePathwayStakeResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgStakeToGanglion(_message.Message):
    __slots__ = ("creator", "amount")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    creator: str
    amount: int
    def __init__(self, creator: _Optional[str] = ..., amount: _Optional[int] = ...) -> None: ...

class MsgStakeToGanglionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgClaimReward(_message.Message):
    __slots__ = ("creator",)
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    creator: str
    def __init__(self, creator: _Optional[str] = ...) -> None: ...

class MsgClaimRewardResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUnstakeFromGanglion(_message.Message):
    __slots__ = ("creator", "amount")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    creator: str
    amount: int
    def __init__(self, creator: _Optional[str] = ..., amount: _Optional[int] = ...) -> None: ...

class MsgUnstakeFromGanglionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdatePathway(_message.Message):
    __slots__ = ("creator", "id", "name", "description", "is_public", "ions", "field_maps_base64")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    IS_PUBLIC_FIELD_NUMBER: _ClassVar[int]
    IONS_FIELD_NUMBER: _ClassVar[int]
    FIELD_MAPS_BASE64_FIELD_NUMBER: _ClassVar[int]
    creator: str
    id: int
    name: str
    description: str
    is_public: bool
    ions: _containers.RepeatedScalarFieldContainer[str]
    field_maps_base64: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, creator: _Optional[str] = ..., id: _Optional[int] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., is_public: bool = ..., ions: _Optional[_Iterable[str]] = ..., field_maps_base64: _Optional[_Iterable[str]] = ...) -> None: ...

class MsgUpdatePathwayResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRemoveIon(_message.Message):
    __slots__ = ("creator",)
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    creator: str
    def __init__(self, creator: _Optional[str] = ...) -> None: ...

class MsgRemoveIonResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRemovePathway(_message.Message):
    __slots__ = ("creator", "id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    id: int
    def __init__(self, creator: _Optional[str] = ..., id: _Optional[int] = ...) -> None: ...

class MsgRemovePathwayResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSetAllowedIps(_message.Message):
    __slots__ = ("creator", "ips")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    IPS_FIELD_NUMBER: _ClassVar[int]
    creator: str
    ips: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, creator: _Optional[str] = ..., ips: _Optional[_Iterable[str]] = ...) -> None: ...

class MsgSetAllowedIpsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/error_code.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/error_code.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fneurion/fusion/error_code.proto\x12\x0eneurion.fusion*\xf5\x03\n\tErrorCode\x12\x15\n\x11\x45rrorCode_NOERROR\x10\x00\x12\x1d\n\x19\x45rrorCode_INVALID_ADDRESS\x10\x01\x12!\n\x1d\x45rrorCode_INVALID_TASK_STATUS\x10\x02\x12\x1a\n\x16\x45rrorCode_NOT_PROPOSER\x10\x03\x12\x1b\n\x17\x45rrorCode_NOT_VALIDATOR\x10\x04\x12\x1e\n\x1a\x45rrorCode_ALREADY_ASSIGNED\x10\x05\x12\x1e\n\x1a\x45rrorCode_STAKE_NOT_ENOUGH\x10\x06\x12\x1f\n\x1b\x45rrorCode_ALREADY_SUBMITTED\x10\x07\x12\x1c\n\x18\x45rrorCode_NOT_AUTHORIZED\x10\x08\x12!\n\x1d\x45rrorCode_MIN_TIME_NOT_PASSED\x10\t\x12\x1e\n\x1a\x45rrorCode_COLLECTION_ERROR\x10\n\x12\x19\n\x15\x45rrorCode_BLACKLISTED\x10\x0b\x12\x1f\n\x1b\x45rrorCode_ALREADY_VALIDATOR\x10\x0c\x12\x1e\n\x1a\x45rrorCode_ALREADY_PROPOSER\x10\r\x12\x19\n\x15\x45rrorCode_WRONG_ROUND\x10\x0e\x12\x1d\n\x19\x45rrorCode_PENDING_DISPUTE\x10\x0f\x42\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.error_code_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_ERRORCODE']._serialized_start=52
  _globals['_ERRORCODE']._serialized_end=553
# @@protoc_insertion_point(module_scope)
